﻿#include "character.h"
#include <QtXml/qdom.h>
#include <QFile>
#include <QDebug>
#include "interface.h"

std::vector<CCharacter::SChampDBData>   CCharacter::dataBase;

//------------------------------------------------------
CCharacter::CCharacter()
{
    portrait = -1;

    for (int i = 0; i < eBodyPartCount; ++i)
        bodyObjects[i] = -1;
}

//------------------------------------------------------
bool CCharacter::isDead()
{
    return (stats[eStatHealth].value <= 0);
}

//------------------------------------------------------
void CCharacter::fromDB(int num)
{
    SChampDBData&   db = dataBase[num];

    firstName = db.firstName;
    lastName = db.lastName;
    portrait = db.portrait;

    for (size_t i = 0; i < eStatCount; ++i)
    {
        stats[i].startValue = db.stats[i];
        stats[i].maxValue = db.stats[i];
        stats[i].value = db.stats[i];
    }
    stats[eStatLoad].value = 0;
}

//------------------------------------------------------
void CCharacter::readCharactersDB()
{
    // XML tags in the same order as EStatsNames
    static const char   statNames[][20] =
    {
        "health",
        "stamina",
        "mana",
        "strength",
        "dexterity",
        "wisdom",
        "vitality",
        "anti_magic",
        "anti_fire",
        "load"
    };

    QDomDocument doc;

    QFile f("databases/champions.xml");
    f.open(QIODevice::ReadOnly);
    doc.setContent(&f);
    f.close();

    QDomElement root = doc.documentElement();
    QDomElement champion = root.firstChild().toElement();

    while(!champion.isNull())
    {
        if (champion.tagName() == "champion")
        {
            SChampDBData   newChamp;

            std::string firstNameId = champion.attribute("firstName").toUtf8().constData();
            newChamp.firstName = interface.getText(firstNameId);
            std::string lastNameId = champion.attribute("lastName").toUtf8().constData();
            newChamp.lastName = interface.getText(lastNameId);

            QDomElement champInfo = champion.firstChild().toElement();

            while(!champInfo.isNull())
            {
                if (champInfo.tagName() == "portrait")
                {
                    newChamp.portrait = champInfo.text().toInt();
                }
                else
                {
                    for (size_t i = 0; i < eStatCount; ++i)
                    {
                        if (champInfo.tagName() == QString(statNames[i]))
                            newChamp.stats[i] = champInfo.text().toInt();
                    }
                }

                champInfo = champInfo.nextSibling().toElement();
            }
            dataBase.push_back(newChamp);
        }
        champion = champion.nextSibling().toElement();
    }
}
